@@ -7,7 +7,7 @@
 #' @param mm month - single number denoting month
 #' @param dd day - single number denoting day
 #' @param hh hour - single number denoting initial hour of sounding; for most stations this measurement is done twice a day (i.e. at 12 and 00 UTC), sporadically 4 times a day
-#' @importFrom utils download.file read.fwf
+#' @importFrom utils read.fwf
 #' @return Returns two lists with values described at: weather.uwyo.edu ; The first list contains:
 #' \enumerate{
 #'  \item PRES - Pressure (hPa)
@@ -32,7 +32,13 @@
 #'
 #' @examples 
 #' \donttest{
-#'   profile <- sounding_wyoming(wmo_id = 12120, yy = 2019, mm = 4, dd = 4, hh = 0)
+#' # generate the date to download randomly:
+#' 
+#'   profile = sounding_wyoming(wmo_id = 12120, 
+#'                              yy = sample(2000:2019,1),
+#'                              mm = sample(1:12,1), 
+#'                              dd = sample(1:20,1), 
+#'                              hh = 0)
 #'   head(profile)
 #'   plot(profile[[1]]$HGHT, profile[[1]]$PRES, type = 'l')
 #' }
@@ -56,7 +62,8 @@ sounding_wyoming <- function(wmo_id, yy, mm, dd, hh){
                 yy, "&MONTH=", mm, "&FROM=", dd, hh, "&TO=", dd, hh, "&STNM=", wmo_id)
 
   temp <- tempfile()
-  download.file(url, temp)
+  test_url(url, temp)
+  #download.file(url, temp)
 
   txt <- read.fwf(file = temp, widths = 1000)
   sects <- grep(pattern = "PRE>", x = txt$V1)
